This crate is a API helper for SCP: Secret Laboratory game. Official API reference can be found here.
Modules
- This module contains functionality that can be used for working with the
ipAPI request. - This module contains structs and functions these can be used for working with the
serverinfoAPI request.